package btc.loader

import java.io.File
import java.text.SimpleDateFormat
import java.util.Calendar

import net.liftweb.common. { Loggable, Logger }
import net.liftweb.json. { DefaultFormats, parse }

import scala.util.control.Breaks. { break, breakable }

class Main extends xsbti.AppMain with Logger with Loggable {

	protected class Exit(val code: Int) extends xsbti.Exit

	def run(configuration: xsbti.AppConfiguration) = {

    Main.main(configuration.arguments)

    new Exit(0)

	}
}

object Main extends Logger with Loggable {

  protected var zipped: Boolean = _
  protected var requestMax: Int = _
  protected var requestDelay: Int = _
  protected var from: Long = _
  protected var till: Long = _
  protected var output: File = _
  protected var symbols: Array[String] = null

  protected val dateFormatter = new SimpleDateFormat("yyyy-MM-dd")

  def main(args: Array[String]) {

    zipped = false
    requestMax = 3
    requestDelay = 60
    from = 0
    till = System.currentTimeMillis
    output = new File(".")
    symbols = Array[String]()

    var i = 0

    while(i < args.size) {

      args(i) match {

        case "-d" =>
          i += 1
          requestDelay = args(i).toInt

        case "-f" =>
          i += 1
          from = dateFormatter.parse(args(i)).getTime

        case "-o" =>
          i += 1
          output = new File(args(i))

        case "-t" =>
          i += 1
          till = dateFormatter.parse(args(i)).getTime

        case "-x" =>
          i += 1
          requestMax = args(i).toInt

        case "-z" =>
          zipped = true

        case symbol: String =>
          symbols = symbols :+ symbol

        case _ =>
          error("Unfamiliar with argument: " + args(i))
          return

      }

      i += 1

    }

    val calendar = Calendar.getInstance

    calendar.setTimeInMillis(from)
    calendar.set(Calendar.HOUR_OF_DAY, 0)
    calendar.set(Calendar.MINUTE, 0)
    calendar.set(Calendar.SECOND, 0)
    calendar.set(Calendar.MILLISECOND, 0)
    from = calendar.getTimeInMillis

    calendar.setTimeInMillis(till)
    calendar.set(Calendar.HOUR_OF_DAY, 0)
    calendar.set(Calendar.MINUTE, 0)
    calendar.set(Calendar.SECOND, 0)
    calendar.set(Calendar.MILLISECOND, 0)
    till = calendar.getTimeInMillis

    new Loader(
      zipped,
      requestMax,
      requestDelay,
      from,
      till,
      output,
      symbols)

  }
}

